# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/project_domain_attributes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.admin import matchable_resource_pb2 as flyteidl_dot_admin_dot_matchable__resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.flyteidl/admin/project_domain_attributes.proto\x12\x0e\x66lyteidl.admin\x1a\'flyteidl/admin/matchable_resource.proto\"\xa0\x01\n\x17ProjectDomainAttributes\x12\x18\n\x07project\x18\x01 \x01(\tR\x07project\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12S\n\x13matching_attributes\x18\x03 \x01(\x0b\x32\".flyteidl.admin.MatchingAttributesR\x12matchingAttributes\"o\n$ProjectDomainAttributesUpdateRequest\x12G\n\nattributes\x18\x01 \x01(\x0b\x32\'.flyteidl.admin.ProjectDomainAttributesR\nattributes\"\'\n%ProjectDomainAttributesUpdateResponse\"\x9d\x01\n!ProjectDomainAttributesGetRequest\x12\x18\n\x07project\x18\x01 \x01(\tR\x07project\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12\x46\n\rresource_type\x18\x03 \x01(\x0e\x32!.flyteidl.admin.MatchableResourceR\x0cresourceType\"m\n\"ProjectDomainAttributesGetResponse\x12G\n\nattributes\x18\x01 \x01(\x0b\x32\'.flyteidl.admin.ProjectDomainAttributesR\nattributes\"\xa0\x01\n$ProjectDomainAttributesDeleteRequest\x12\x18\n\x07project\x18\x01 \x01(\tR\x07project\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12\x46\n\rresource_type\x18\x03 \x01(\x0e\x32!.flyteidl.admin.MatchableResourceR\x0cresourceType\"\'\n%ProjectDomainAttributesDeleteResponseB\xc2\x01\n\x12\x63om.flyteidl.adminB\x1cProjectDomainAttributesProtoP\x01Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin\xa2\x02\x03\x46\x41X\xaa\x02\x0e\x46lyteidl.Admin\xca\x02\x0e\x46lyteidl\\Admin\xe2\x02\x1a\x46lyteidl\\Admin\\GPBMetadata\xea\x02\x0f\x46lyteidl::Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.admin.project_domain_attributes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.flyteidl.adminB\034ProjectDomainAttributesProtoP\001Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin\242\002\003FAX\252\002\016Flyteidl.Admin\312\002\016Flyteidl\\Admin\342\002\032Flyteidl\\Admin\\GPBMetadata\352\002\017Flyteidl::Admin'
  _globals['_PROJECTDOMAINATTRIBUTES']._serialized_start=108
  _globals['_PROJECTDOMAINATTRIBUTES']._serialized_end=268
  _globals['_PROJECTDOMAINATTRIBUTESUPDATEREQUEST']._serialized_start=270
  _globals['_PROJECTDOMAINATTRIBUTESUPDATEREQUEST']._serialized_end=381
  _globals['_PROJECTDOMAINATTRIBUTESUPDATERESPONSE']._serialized_start=383
  _globals['_PROJECTDOMAINATTRIBUTESUPDATERESPONSE']._serialized_end=422
  _globals['_PROJECTDOMAINATTRIBUTESGETREQUEST']._serialized_start=425
  _globals['_PROJECTDOMAINATTRIBUTESGETREQUEST']._serialized_end=582
  _globals['_PROJECTDOMAINATTRIBUTESGETRESPONSE']._serialized_start=584
  _globals['_PROJECTDOMAINATTRIBUTESGETRESPONSE']._serialized_end=693
  _globals['_PROJECTDOMAINATTRIBUTESDELETEREQUEST']._serialized_start=696
  _globals['_PROJECTDOMAINATTRIBUTESDELETEREQUEST']._serialized_end=856
  _globals['_PROJECTDOMAINATTRIBUTESDELETERESPONSE']._serialized_start=858
  _globals['_PROJECTDOMAINATTRIBUTESDELETERESPONSE']._serialized_end=897
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/sagemaker/parameter_ranges.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1flyteidl/plugins/sagemaker/parameter_ranges.proto\x12\x1a\x66lyteidl.plugins.sagemaker\"c\n\x19HyperparameterScalingType\"F\n\x05Value\x12\x08\n\x04\x41UTO\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\x0f\n\x0bLOGARITHMIC\x10\x02\x12\x16\n\x12REVERSELOGARITHMIC\x10\x03\"\xb4\x01\n\x18\x43ontinuousParameterRange\x12\x1b\n\tmax_value\x18\x01 \x01(\x01R\x08maxValue\x12\x1b\n\tmin_value\x18\x02 \x01(\x01R\x08minValue\x12^\n\x0cscaling_type\x18\x03 \x01(\x0e\x32;.flyteidl.plugins.sagemaker.HyperparameterScalingType.ValueR\x0bscalingType\"\xb1\x01\n\x15IntegerParameterRange\x12\x1b\n\tmax_value\x18\x01 \x01(\x03R\x08maxValue\x12\x1b\n\tmin_value\x18\x02 \x01(\x03R\x08minValue\x12^\n\x0cscaling_type\x18\x03 \x01(\x0e\x32;.flyteidl.plugins.sagemaker.HyperparameterScalingType.ValueR\x0bscalingType\"3\n\x19\x43\x61tegoricalParameterRange\x12\x16\n\x06values\x18\x01 \x03(\tR\x06values\"\x89\x03\n\x13ParameterRangeOneOf\x12t\n\x1a\x63ontinuous_parameter_range\x18\x01 \x01(\x0b\x32\x34.flyteidl.plugins.sagemaker.ContinuousParameterRangeH\x00R\x18\x63ontinuousParameterRange\x12k\n\x17integer_parameter_range\x18\x02 \x01(\x0b\x32\x31.flyteidl.plugins.sagemaker.IntegerParameterRangeH\x00R\x15integerParameterRange\x12w\n\x1b\x63\x61tegorical_parameter_range\x18\x03 \x01(\x0b\x32\x35.flyteidl.plugins.sagemaker.CategoricalParameterRangeH\x00R\x19\x63\x61tegoricalParameterRangeB\x16\n\x14parameter_range_type\"\xfc\x01\n\x0fParameterRanges\x12r\n\x13parameter_range_map\x18\x01 \x03(\x0b\x32\x42.flyteidl.plugins.sagemaker.ParameterRanges.ParameterRangeMapEntryR\x11parameterRangeMap\x1au\n\x16ParameterRangeMapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x45\n\x05value\x18\x02 \x01(\x0b\x32/.flyteidl.plugins.sagemaker.ParameterRangeOneOfR\x05value:\x02\x38\x01\x42\xf9\x01\n\x1e\x63om.flyteidl.plugins.sagemakerB\x14ParameterRangesProtoP\x01Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins\xa2\x02\x03\x46PS\xaa\x02\x1a\x46lyteidl.Plugins.Sagemaker\xca\x02\x1a\x46lyteidl\\Plugins\\Sagemaker\xe2\x02&Flyteidl\\Plugins\\Sagemaker\\GPBMetadata\xea\x02\x1c\x46lyteidl::Plugins::Sagemakerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.plugins.sagemaker.parameter_ranges_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.flyteidl.plugins.sagemakerB\024ParameterRangesProtoP\001Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins\242\002\003FPS\252\002\032Flyteidl.Plugins.Sagemaker\312\002\032Flyteidl\\Plugins\\Sagemaker\342\002&Flyteidl\\Plugins\\Sagemaker\\GPBMetadata\352\002\034Flyteidl::Plugins::Sagemaker'
  _PARAMETERRANGES_PARAMETERRANGEMAPENTRY._options = None
  _PARAMETERRANGES_PARAMETERRANGEMAPENTRY._serialized_options = b'8\001'
  _globals['_HYPERPARAMETERSCALINGTYPE']._serialized_start=81
  _globals['_HYPERPARAMETERSCALINGTYPE']._serialized_end=180
  _globals['_HYPERPARAMETERSCALINGTYPE_VALUE']._serialized_start=110
  _globals['_HYPERPARAMETERSCALINGTYPE_VALUE']._serialized_end=180
  _globals['_CONTINUOUSPARAMETERRANGE']._serialized_start=183
  _globals['_CONTINUOUSPARAMETERRANGE']._serialized_end=363
  _globals['_INTEGERPARAMETERRANGE']._serialized_start=366
  _globals['_INTEGERPARAMETERRANGE']._serialized_end=543
  _globals['_CATEGORICALPARAMETERRANGE']._serialized_start=545
  _globals['_CATEGORICALPARAMETERRANGE']._serialized_end=596
  _globals['_PARAMETERRANGEONEOF']._serialized_start=599
  _globals['_PARAMETERRANGEONEOF']._serialized_end=992
  _globals['_PARAMETERRANGES']._serialized_start=995
  _globals['_PARAMETERRANGES']._serialized_end=1247
  _globals['_PARAMETERRANGES_PARAMETERRANGEMAPENTRY']._serialized_start=1130
  _globals['_PARAMETERRANGES_PARAMETERRANGEMAPENTRY']._serialized_end=1247
# @@protoc_insertion_point(module_scope)
